
local gridSize = 40
local slideTime = 3

local pts = {{1, 2}, {13, 2}, {7, 8}}
local nPoints = #pts

for i = 1, nPoints do
  pts[i][1] = pts[i][1] * gridSize
  pts[i][2] = pts[i][2] * gridSize
end

local mid = {}
for i = 1, nPoints do
  mid[i] = {(pts[i][1] + pts[i%nPoints+1][1]) / 2,
            (pts[i][2] + pts[i%nPoints+1][2]) / 2}
end

local bez = {}
-- Love supports quadratic Beziers so no need for fancy stuff
for i = 1, 3 do
  bez[i] = love.math.newBezierCurve(mid[(i+nPoints-2)%nPoints+1][1],
                                    mid[(i+nPoints-2)%nPoints+1][2],
    pts[i][1], pts[i][2],
    mid[i][1], mid[i][2])
end


local slide = 0
local time = 0
local t2 = 0
local x1, y1

function love.update(dt)
  time = time - dt
  if time <= 0 then
    time = slideTime
    slide = slide + 1
    t2 = 0
    if slide > 9 then slide = 7 end
  end
  if slide >= 7 then
    x1, y1 = bez[slide - 6]:evaluate(t2)
    t2 = t2 + dt / slideTime
    if t2 >= 1 then t2 = 1 end
  end
end

function love.draw()
  for i = 1, 3 do
    love.graphics.circle("fill", pts[i][1], pts[i][2], 4)
  end
  local text = ""
  if slide == 1 then
    text = "Inputs"
  elseif slide == 2 then
    text = "Inputs + Midpoints"
  elseif slide == 3 then
    text = "Inputs + Midpoints + Curves"
  elseif slide == 4 then
    text = "Curve 1"
  elseif slide == 5 then
    text = "Curve 2"
  elseif slide == 6 then
    text = "Curve 3"
  elseif slide >= 7 then
    text = "Trajectory"
  end
  love.graphics.print(text)
  if slide >= 2 then
    love.graphics.setColor(0.5, 0.5, 0)
    for i = 1, 3 do
      love.graphics.circle("fill", mid[i][1], mid[i][2], 4)
    end
    love.graphics.setColor(1, 1, 1)
  end
  if slide >= 3 then
    for i = 1, 3 do
      if i == 1 and slide == 4
         or i == 2 and slide == 5
         or i == 3 and slide == 6
         or slide == 3
      then
        love.graphics.setColor(1, 1, 1)
      else
        love.graphics.setColor(1, 1, 1, 0.5)
      end
      love.graphics.line(bez[i]:render(5))
      love.graphics.setColor(1, 1, 1)
    end
  end
  if slide >= 7 then
    love.graphics.setColor(0, 1, 0)
    love.graphics.circle("fill", x1, y1, 3)
    love.graphics.setColor(1, 1, 1)
  end
end

function love.keypressed(k)if k=="escape" then love.event.quit()return end end
